# python-bydhvs
Python Wrapper for BYD b-Box HVM/HVS/LVS

Installation
------------
The module is available from the [Python Package Index](https://pypi.python.org/pypi)

    $ pip3 install bydhvs

On a Fedora-based system or a CentOS/RHEL host with EPEL.

    $ sudo dnf -y install python3-bydhvs

Usage
-----

The file ``example.py`` contains an example about how to use this module.

License
-------

``python-byd`` is licensed under GPL-3.0 license, for more details check LICENSE.
